@@ -1,7 +1,7 @@
 package Perinci::CmdLine;
 
-our $DATE = '2014-09-16'; # DATE
-our $VERSION = '1.31'; # VERSION
+our $DATE = '2014-10-03'; # DATE
+our $VERSION = '1.32'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -630,7 +630,8 @@ sub hook_display_result {
     if (!defined($utf8) && $r->{subcommand_data}) {
         $utf8 //= $r->{subcommand_data}{use_utf8};
     }
-    $utf8 //= $self->use_utf8;
+    $utf8 //= $self->use_utf8
+        if $self->can("use_utf8");
     if ($utf8) {
         binmode(STDOUT, ":utf8");
     }
@@ -844,7 +845,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.31 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-09-16.
+This document describes version 1.32 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-10-03.
 
 =head1 SYNOPSIS
 
@@ -961,7 +962,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine>.
 
 =head1 BUGS
 
